Before you start
================

It will be helpful to have these steps already completed before you start the tutorial modules:

* Make sure you have `python 3.6`__.
  
__ https://www.python.org/downloads/release/python-360/

* Make sure you have `GNU make tools`__.
__ https://www.gnu.org/software/make/
and `compilers`__.

__ https://gcc.gnu.org/

* Install docker

* Download OpenFOAM image with:

.. code:: bash

    docker pull cfdengine/openfoam

* Download redis image with:

.. code:: bash

    docker pull redis

